

Export-RIB()               Unix Programmer's Manual               Export-RIB()


NAME
     exp_rib - RenderMan RIB geometry export filter

SYNOPSIS

     This man page  describes  the  options  specific  to  the  full  featured
     RenderMan RIB geometry export converter.

EXAMPLE CONVERSION SYNTAX

     To convert a 3D Studio file to RIB using the default parameters listed in
     the setup.ini file:

          pt -i 3ds -o rib filename.3ds

     To convert a Lightwave file to RIB  and  override  some  of  the  default
     options in setup.ini:

          pt -i lw -o rib -out-output-texture-data = yes filename.lw

OVERVIEW

     The RIB geometry export converter writes out  the  scene  database  to  a
     RenderMan RIB v3.1 compliant ASCII file which can then be read into other
     programs, or more likely, be sent off to PIXAR's RenderMan renderer.

     The converter writes out a full RIB specification that can be read into a
     RIB  compliant renderer and rendered immediately. It has been tested with
     PIXAR's RenderMan for  Windows  v1.2.  The  converter  primarily  outputs
     optimized  indexed polygon arrays using the "PointsPolygon" primitive but
     will also output NURB and Bicubic patch primitives directly.

COMMAND LINE OPTIONS

     The following options are specific to this import converter:

     -o rib
          This is the mandatory command line option which specifies  that  the
          data is to be exported using the RIB format converter.

     -out-rib-output-txtr-data = [ yes | no ]
          If this option is set to  'yes'  then  texture  mapping  coordinates
          ("st"  array data) and texture mapping commands ("MakeTexture") will
          be output to the RIB file for those primitives which  references  2d
          textures. If set to 'no' then no texture mapping related information
          will be output.

     -out-line-ending = [ cr | lf | crlf ]
          This common option selects which line terminator is to be  used  for
          the ASCII output file. Files destined for DOS/PC machines should use
          'crlf', files for UNIX  machines  should  use  'lf'  and  files  for
          Macintosh  machines  should  use  'cr'.   The default is specific to
          which machine this converter is presently  running  on:  'crlf'  for
          DOS/PC,  'lf'  for UNIX and 'cr' for Macintosh. This option normally
          does not have to be specified unless you will be using the  exported
          ASCII file on a different type of computer.


                                                                             1



Export-RIB()               Unix Programmer's Manual               Export-RIB()


CONVERSION NOTES

     If NURB or Bicubic patches exist within the converter's internal database
     then  these  will be written to the RIB file as "NuPatch" and "PatchMesh"
     primitives, respectively.

     Any other primitives will be written as optimized indexed polygons  using
     the  "PointsPolygon"  primitive.  If  a polygon has holes then it will be
     triangulated. If  vertex  normals,  vertex  texture  coordinates,  vertex
     colors  or  vertex  opacity  values are associated with the polygons then
     they will be output as indexed arrays as well ("N", "st",  "Cs"  and  "O"
     RIB arrays).

     If, within the converter's database, multiple  materials  are  associated
     with  a  single  object  then this converter will explode such objects so
     that each exported "PointsPolygon" RIB primitive is associated with  only
     one material definition.

     The exported RIB file contains a line that begins with "# display".  This
     line should be uncommented if you want the rendered image to be saved out
     to the specified TIFF file (see the RIB file for details).

LIMITATIONS

     No NURB trimming curves are output at this time.

     The exported RIB file references only the "plastic" and  "paintedplastic"
     default  RenderMan  shaders. This seriously limits the amount of material
     information that can be exported to the RIB file due to the simplicity of
     these shaders.

     If more than one texture map is assigned to a surface then only the first
     one will be output in the file.

     Texture mapping scale and offset parameters are not  output  to  the  RIB
     file due to lack of such parameters in the standard RIB shaders.

     No light source decay is output  because  the  standard  RenderMan  light
     source shaders do not support arbitrary decay.

Other Copyrights and Trademarks

     RenderMan is a registered trademark of Pixar.

     The RenderMan Interface Procedures and Protocol are Copyright 1988, 1989,
     Pixar. All Rights Reserved.












                                                                             2

