

Export-VRML()              Unix Programmer's Manual              Export-VRML()


NAME
     exp_vrml - VRML geometry export filter

SYNOPSIS

     This man page describes the options specific to the VRML geometry  export
     converter.

EXAMPLE CONVERSION SYNTAX

     To convert a 3D Studio file to VRML using the default  parameters  listed
     in the setup.ini file:

          pt -i 3ds -o vrml filename.3ds

     To convert a Lightwave file to VRML and  override  some  of  the  default
     options in setup.ini:

          pt -i lw -o vrml -out-output-texture-data = yes filename.lw

OVERVIEW

     VRML is an ASCII file format for describing 3d scenes  which  is  primary
     used  in  interactive  virtual  reality  applications. This VRML geometry
     export converter writes out the scene database to a VRML  v1.0  compliant
     file.

     Concave polygons and polygons with  holes  will  be  triangulated  before
     being  output as indexed polygon primitives. Cameras, lights and material
     definitions will also be output in addition to the basic geometry.  Since
     there  is  no  ambient  light  type in the VRML specification the ambient
     light color is multiplied into each material's ambient color.

     Normals and texture coordinates are bound on a  per-vertex  basis,  while
     materials  are  bound  on  a  per-face  (per-polygon)  basis. If multiple
     textures are assigned to  a  single  object  then  that  object  will  be
     exploded  into separate indexed polygon primitives before being output to
     the VRML file, with each primitive being assigned a single texture.

     Note that this converter does not allow anchors or inlines to  be  output
     along  with  the  data.  These  commands  can  be  inserted into the file
     manually.

     As with all other export converters, the exported  indexed  polygons  are
     automatically  welded and optimized before being output to the VRML file.
     This  optimization  step  includes  removing  redundant  coordinates  and
     creating vertex normals if none exist. Thus, the exported geometry should
     be in a good, compact form for efficient VRML usage.

COMMAND LINE OPTIONS

     The following options are specific to this export converter:

     -o vrml
          This is the mandatory command line option which specifies  that  the
          data is to be exported using the VRML format converter.


                                                                             1



Export-VRML()              Unix Programmer's Manual              Export-VRML()


     -out-vrml-file-version = [ 1 | 2 ]
          This selects what VRML file format to save the data into.  '1'  will
          output  in  the  original VRML 1.0 format whereas '2' will output in
          the new 'Moving Worlds' format.

     -out-vrml-embed_texture_images = [ yes | no ]
          If this option is set to 'yes'  and  the  '-out-output-texture-data'
          option  is  set  to  'yes' then any texture images referenced by the
          VRML data will be embedded directly within the file.  The  converter
          can  convert  and embed the following file formats (and all of their
          variations): BMP, FLIC, GIF, CEL (Autodesk), JPEG, Targa and TIFF.

     -out-vrml-output-texture-data = [ yes | no ]
          If this option is set to 'yes' then texture mapping coordinates  and
          references  will  be  output  to  the VRML file for those primitives
          which references 2d textures. If set to 'no' then no texture mapping
          related information will be output.

     -out-vrml-add-url-prefix = [ yes | no ]
          If this option is set to 'yes' then all bitmap  filenames  (used  in
          association  with  a  texture  map) will be prefixed with the string
          specified by the '-out-vrml-url-string' option below.  For  example,
          if a texture references the filename 'c:/nugraf/textures/bitmap.tif'
          within the NuGraf database, and the URL is specified on this  dialog
          box  as "http://www.okino.com/images/" then the bitmap filename will
          be       stored       in       the        VRML        file        as
          'http://www.okino.com/images/bitmap.tif'.

     -out-vrml-url-string = "URL string goes here"
          This is the URL string that  will  be  prefixed  before  any  bitmap
          filenames  in the VRML file. You must enable the '-out-vrml-add-url-
          prefix' option above for this string to take affect.

     -out-line-ending = [ cr | lf | crlf ]
          This common option selects which line terminator is to be  used  for
          the ASCII output file. Files destined for DOS/PC machines should use
          'crlf', files for UNIX  machines  should  use  'lf'  and  files  for
          Macintosh  machines  should  use  'cr'.   The default is specific to
          which machine this converter is presently  running  on:  'crlf'  for
          DOS/PC,  'lf'  for UNIX and 'cr' for Macintosh. This option normally
          does not have to be specified unless you will be using the  exported
          ASCII file on a different type of computer.

VRML SITES ON THE INTERNET

     http://www.vrml.org
          Home site of VRML organization.

     http://www.sdsc.edu/vrml
          Virtual Reality Modeling Language Repository.








                                                                             2

