

Export-Wavefront()         Unix Programmer's Manual         Export-Wavefront()


NAME
     exp_wave - Wavefront .OBJ geometry export filter

SYNOPSIS

     This man page  describes  the  options  specific  to  the  Wavefront  OBJ
     geometry export converter.

EXAMPLE CONVERSION SYNTAX

     To convert a 3D Studio file to Wavefront  using  the  default  parameters
     listed in the setup.ini file:

          pt -i 3ds -o wave filename.3ds

     To convert a Lightwave file to Wavefront and override some of the default
     options in setup.ini:

          pt -i lw -o wave -out-output-material-file = no filename.lw

OVERVIEW

     The Wavefront OBJ geometry export converter writes out the scene database
     as  a  series  of  indexed  polygons (faces and their associated indices)
     along with optional normal and texture data (if  its  exists  within  the
     database).  A  Wavefront  material  definition  file  (.mtl)  can also be
     exported.

     The exported .OBJ file will be compliant with  the  Wavefront  .OBJ  file
     format  version  2.11  which  defines  polygonal  geometry.  Higher order
     primitives, such as NURB and  bicubic  patches  will  be  converted  into
     convex polygons before begin output.

     Any concave polygons or polygons with holes will be  triangulated  before
     being output to the .OBJ file.

     Polygons that belong to the same object within the  converter's  internal
     database  will  output as a single unique group within the .OBJ file with
     the group's name set equal to the internal object name; the group name is
     specified with the "g" command in the file.

     No hierarchy information is output since the  .OBJ  file  format  has  no
     methods  to  describing  hierarchy;  each  sub-object of a hierarchy will
     nonetheless be exported as a unique group whose name's match the original
     object names in the internal database hierarchy.

COMMAND LINE OPTIONS

     The following options are specific to this export converter:

     -o wave
          This is the mandatory command line option which specifies  that  the
          data is to be exported using the Wavefront OBJ format converter.





                                                                             1



Export-Wavefront()         Unix Programmer's Manual         Export-Wavefront()


     -out-wave-output-material-file = [ yes | no ]
          If this option is set to 'yes' then a Wavefront compatible  material
          file  will  be  output along with the main .obj geometry file.  This
          file will have the same root filename as the input filename but with
          a   .mtl  file  extension  (ie.:  input  =  filename.3ds,  output  =
          filename.obj and filename.mtl).  The material file will list all  of
          the  material  definitions  referenced  by  the  geometry as well as
          specify some of the material properties such as Ns, Ka, Kd,  Ks  and
          the shading model (see below for their explanations).  Note that the
          Wavefront  material  file  does  not  accommodate  texture  filename
          information.  If  this  option  is set to 'no' then no material file
          will be output.

     -out-line-ending = [ cr | lf | crlf ]
          This common option selects which line terminator is to be  used  for
          the ASCII output file. Files destined for DOS/PC machines should use
          'crlf', files for UNIX  machines  should  use  'lf'  and  files  for
          Macintosh  machines  should  use  'cr'.   The default is specific to
          which machine this converter is presently  running  on:  'crlf'  for
          DOS/PC,  'lf'  for UNIX and 'cr' for Macintosh. This option normally
          does not have to be specified unless you will be using the  exported
          ASCII file on a different type of computer.

MATERIAL FILE PARAMETERS

     If the '-out-output-material-file' option  is  enabled  then  a  material
     definition  file (.mtl) will be output along with the geometry file. This
     file  lists  attributes  of  various  materials.  The  mapping  from  the
     converter's  internal  parameters to the .mtl parameters are described as
     follows:

          Ns = Phong specular component. Ranges from 0 to 200.

          Kd = Diffuse color weighted by the diffuse coefficient.

          Ka = Ambient color weighted by the ambient coefficient.

          Ks = Specular color weighted by the specular coefficient.

          d = Dissolve  factor  (pseudo-transparency).  This  is  set  to  the
          internal face transparency value.

          illum 2 = Diffuse and specular shading model.

LIMITATIONS

     Since the converter's internal database does not allow  materials  to  be
     assigned  to  specific  vertices  (it only allows color to be assigned to
     vertices), it will not output any  material  assignments  at  the  vertex
     level.   However,  it  will  output material assignments on a per polygon
     basis.







                                                                             2

