

Import-IGES()              Unix Programmer's Manual              Import-IGES()


NAME
     imp_iges - IGES geometry import filter

SYNOPSIS

     This man page describes the options specific to  the  IGES  4.0  geometry
     import converter.

EXAMPLE CONVERSION SYNTAX

     To convert an IGES file to Wavefront using the default parameters  listed
     in the setup.ini file:

          pt -i iges -o wave filename.igs

     To convert an IGES file to VRML and override some of the default  options
     in setup.ini:

          pt -i iges -in-iges-verbose = yes -o vrml filename.igs

OVERVIEW

     This geometry import  converter  reads  in  IGES  4.0  ASCII  files.  All
     entities  are  parsed  and stored temporarily in memory but only entities
     106 (polygons) and 128 (NURB patches) are currently sent to the  internal
     geometry database.

     All polygonal data will be stored internally using one 'Indexed  Polygon'
     (mesh)  primitive.  NURB  data  will be stored internally in their native
     form.

COMMAND LINE OPTIONS

     The following options are specific to this import converter:

     -i iges
          This is the optional command line option which  specifies  that  the
          input  data  is  in  the IGES file format. If not specified then the
          converter will try to guess the input file's format  from  its  file
          extension (.igs or .iges) and then from the contents of its file.

     -in-iges-compute-normals = [ yes | no ]
          If set to 'yes' then new vertex  normals  will  be  computed  for  a
          polygon  if  it  does  not  have  any  vertex  normals  already. The
          smoothing criterion is based on the angle between abutting polygons;
          common smoothed vertex normals will be computed if the angle between
          their  geometric  surfaces  normals  is  less  than  the  '-in-iges-
          smoothing-angle'  angle  described below. If set to 'no' then no new
          vertex normals will be created.

     -in-iges-smoothing-angle = #
          This option sets the cut-off smoothing angle (in  degrees)  used  by
          the  vertex  normal  computation algorithm. If the angle between two
          abutting polygons is greater than this number then no smoothing will
          occur  (a  crease  will  be  evident between the two polygons), else
          smoothing will occur where the polygons meet. The default  angle  is


                                                                             1



Import-IGES()              Unix Programmer's Manual              Import-IGES()


          30 degrees.

     -in-iges-debug-mode = [ yes | no ]
          If set to 'yes' then this converter will print out information about
          the tokens it is currently parsing in the file.

     -in-iges-verbose = [ yes | no ]
          If  set  to  'yes'  then  this  converter  will  print  out  verbose
          information  about the IGES file as it is being parsed. No data will
          actually be read into memory.

     -in-iges-report-unsup-entities = [ yes | no ]
          If set to 'yes' then this converter will print out information about
          the IGES entities which are not supported by the IGES parser.

CONVERTER LIMITATIONS

          Due to the fact that some IGES  files  are  not  written  with  100%
          conformance   to  the  IGES  standard  this  import  filter  is  not
          guaranteed to read non-conforming IGES  files.  The  converter  will
          report  the  offending  line  number  which you will have to try and
          correct by hand.

          Only  ASCII  IGES  files  can  be  read.  Binary  reading   is   not
          accommodated.

          This converter is compliant with the IGES v4.0 specification.  Files
          written  with  a newer version of IGES will read in fine but any new
          entities will not be supported.

          Although the IGES format has a rich set of NURB  surfaces,  such  as
          surfaces   of  revolution,  extrusions  and  birail  surfaces,  this
          converter will only read in the NURB patch entity. In  addition,  no
          NURB trimming curve data is converted at this time.
























                                                                             2

