

Import-Imagine()           Unix Programmer's Manual           Import-Imagine()


NAME
     imp_imagine - Imagine or TTDDD geometry import filter

SYNOPSIS

     This man page describes the options specific to  the  Imagine  and  TTDDD
     geometry import converter.

EXAMPLE CONVERSION SYNTAX

     To convert an Imagine file to  Wavefront  using  the  default  parameters
     listed in the setup.ini file:

          pt -i ima -o wave filename.iob

     To convert an Imagine file to VRML  and  override  some  of  the  default
     options in setup.ini:

          pt -i ima -in-ima-smoothing-angle = 40 -o vrml filename.iob

OVERVIEW

     This geometry utility imports Imagine or TTDDD binary geometry files. All
     geometry,  surface  attributes, hierarchy information, lights and cameras
     are properly extracted from the file.

     "Imagine" files typically have file extensions of ".iob", ".obj" or  just
     no  extension  at  all. This converter expects that the file extension be
     renamed to ".iob" so  that  the  file  type  is  not  confused  with  the
     Wavefront file type (which uses ".obj").

     If any of the objects found in the file are reflective then  a  spherical
     environment  map will be added to the surfaces created for the reflective
     objects. By default, all spherical environment maps  will  reference  the
     texture definition: 'imagine_sph_env_map_texture'

     By  default  the  texture  definition  uses   the   TIFF   image   called
     'env_map.tif' which is a dummy filename. You should change this to a nice
     reflective image such as a sky or an image of chrome.

COMMAND LINE OPTIONS

     The following options are specific to this import converter:

     -i ima
          This is the optional command line option which  specifies  that  the
          input data is in the Imagine or TTDDD file formats. If not specified
          then the converter will try to guess the input  file's  format  from
          its  file extension (.iob or .obj) and then from the contents of its
          file.

     -in-ima-calcnormals = [ yes | no ]
          If set to 'yes' then new vertex  normals  will  be  computed  for  a
          polygon  if  it  does  not  have  any  vertex  normals  already. The
          smoothing criterion is based on the angle between abutting polygons;
          common smoothed vertex normals will be computed if the angle between


                                                                             1



Import-Imagine()           Unix Programmer's Manual           Import-Imagine()


          their  geometric  surfaces  normals  is  less  than  the   '-in-ima-
          smoothing-angle'  angle  described below. If set to 'no' then no new
          vertex normals will be created.

     -in-ima-smoothing-angle = #
          This option sets the cut-off smoothing angle (in  degrees)  used  by
          the  vertex  normal  computation algorithm. If the angle between two
          abutting polygons is greater than this number then no smoothing will
          occur  (a  crease  will  be  evident between the two polygons), else
          smoothing will occur where the polygons meet. The default  angle  is
          30 degrees.

     -in-ima-unify-normals = [ yes | no ]
          Most polygons in an Imagine scene file  do  not  have  a  consistent
          orientation  (ie:  some polygons are oriented clockwise while others
          are  oriented  counterclockwise).  In  order   for   the   '-in-ima-
          calcnormals'  option  to  work  all  of  the  polygons  must  have a
          consistent orientation. By setting this option to 'yes'  the  import
          converter  will  walk  across  the  polygon  mesh and re-orient each
          polygon so that it has the  same  orientation  as  its  neighbouring
          polygon(s).  Please  note  that  this will only work if neighbouring
          polygons share the same vertices.

     -in-ima-orient-normals-outward = [ yes | no ]
          In some cases the '-in-ima-unify-normals' option above will flip all
          of  the  geometric  and  vertex  normals  so that they point inwards
          towards the center of each object. If this occurs then  this  option
          should be set to 'yes' so that the normals point outwards.

CREDITS

     Portions of this converter  are  based  on  the  T3D  read/write  library
     developed by Glenn Lewis, used by permission. He can be reached via email
     at  glewis@pcocd2.intel.com   or   via   his   Internet   WEB   site   at
     http://www.c2.org/~glewis.























                                                                             2

