

Import-StudioPro()         Unix Programmer's Manual         Import-StudioPro()


NAME
     imp_stra - Strata StudioPro geometry import filter

SYNOPSIS

     This man page describes the options  specific  to  the  Strata  StudioPro
     geometry import converter.

EXAMPLE CONVERSION SYNTAX

     To convert a  Strata  StudioPro  file  to  Wavefront  using  the  default
     parameters listed in the setup.ini file:

          pt -i sspro -o wave filename.vis

     To convert a Strata StudioPro file to  VRML  and  override  some  of  the
     default options in setup.ini:

          pt -i sspro -in-sspro-debug = yes -o vrml filename.vis

OVERVIEW

     This geometry import converter  reads  files  which  are  in  the  Strata
     StudioPro  file  format.  This  converter  is  probably  one  of the most
     complete Strata StudioPro file readers next to that of the  one  included
     with  Strata  StudioPro  itself. You will find that most StudioPro models
     are of quite high quality, with good use  of  bezier  patches  (for  high
     resolution  modeling)  and  good use of shading + texture mapping to give
     realistic rendered results.

     This converter reads in almost every aspect of a StudioPro file  so  that
     the  file  can  be rendered with little or no modifications by the NuGraf
     renderer, or exported and rendered faithfully with an  external  renderer
     such  as Autodesk's 3D Studio. All in all this is one of the more complex
     import converters. See the end of the this  file  which  describes  which
     entities are handled by this converter.

OVERVIEW

     1. If you are converting a Strata StudioPro file which was obtained  from
     an  Apple  Macintosh  machine  then you must manually add the '.vis' file
     extension to these files.

     2. There is a good chance that this converter will  not  work  on  future
     files saved from Strata's StudioPro program. This is due to the fact that
     the StudioPro file format does not allow unknown  chunks  to  be  skipped
     over.  At such a time this converter will be updated with the file format
     information must be officially obtained from Strata Corporation.

     3. Strata StudioPro files are unusual  because  they  embed  the  texture
     images  right inside the scene file itself (almost all other file formats
     do not do this). This converter extracts these embedded images and stores
     them  on  disk  as  TIFF  files with the first few letters of the texture
     image filename coming from that of the original StudioPro input filename.
     The  TIFF files are stored in the directory controlled by the '-in-sspro-
     texture-dest-directory-type' option described below.


                                                                             1



Import-StudioPro()         Unix Programmer's Manual         Import-StudioPro()


     4. Please be wary of any StudioPro files which were not  written  out  by
     the  Strata  StudioPro program itself - many of such files are corrupt or
     written in a non-standard method. For example,  the  StudioPro  files  on
     Viewpoint  Datalab's  '5  Free  for Siggraph 95' are some such examples -
     they have placed each and every polygon within its own object  definition
     rather  than placing all polygons within one object; in addition, many of
     these example models have incorrect entity offsets  that  are  completely
     illegal.  This  converter  tries to detect such bad files and will try to
     read the files if possible.

COMMAND LINE OPTIONS

     The following options are specific to this import converter:

     -i sspro
          This is the optional command line option which  specifies  that  the
          input data is in Strata StudioPro file format. If not specified then
          the converter will try to guess the input  file's  format  from  its
          file extension and then from the contents of its file. Note that the
          valid file extension is .vis.

     -in-sspro-bezier-subdiv-type = [ low | medium | high | custom ]
          Many StudioPro models are created using Bezier patches  rather  than
          polygons. Bezier patches are stored in the file using a mathematical
          description of a smooth surface instead of a rough approximation  by
          polygons.

          During the export process (say,  when  exporting  a  StudioPro  file
          format  to  3D  Studio),  these  Bezier patches must be converted to
          polygons. The '-in-sspro-bezier-subdiv-type'  option  specifies  how
          finely  to  subdivide  these  bezier  patches when turning them into
          polygonalized surfaces. Higher numbers created  more  polygons,  and
          thus  smoother surfaces, but at the expense of larger exported files
          and longer rendering times.

          The program defaults to 'low' (6x6  subdivisions).  A  good  way  of
          determining  if you need to increase this subdivision level is check
          to see if the exported  file  is  being  rendered  properly  in  the
          destination  renderer.  In  many  cases StudioPro bezier patches are
          highly curved which causes 'non-planar' polygons to  appear  in  the
          exported  file;  these  non-planar  polygons  are  illegal  in  many
          rendering programs. To solve this non-planar polygon  problem,  just
          increase  the  number  of  subdivisions  (so  that  the bezier patch
          surface is turned into many more smaller polygons).

          The following describe the different subdivision levels:

          low = 6x6 = 36 polygons per Bezier patch.

          medium = 20x20 = 400 polygons per Bezier patch.

          high = 50x50 = 2500 polygons per Bezier patch.

          custom = User defined. The subdivision level is set with  the  '-in-
          sspro-bezier-subdivisions' described below.



                                                                             2



Import-StudioPro()         Unix Programmer's Manual         Import-StudioPro()


     -in-sspro-bezier-subdivisions = <num_bezier_subdivisions>
          This is the number of subdivisions in the u  and  v  directions  for
          Bezier patches if the '-in-sspro-bezier-subdiv-type' option above is
          set to 'custom'. If you assign a number  greater  than  1  then  the
          bezier  patch will be subdivided into the square of this number. For
          example, if you assign 4 then 16  polygons  will  be  used.  If  you
          assign 10 then 100 polygons will be used.

     -in-sspro-confirm-txtr-overwrites = [ yes | no ]
          Strata StudioPro files are unusual because they  embed  the  texture
          images  right  inside  the  scene file itself (almost all other file
          formats do not do this).  This  converter  extracts  these  embedded
          images  and  stores  them  on  disk  as  TIFF files in the directory
          controlled  by  the  '-in-sspro-texture-dest-directory-type'  option
          described below.

          If this option is set to 'yes' then the program will  first  confirm
          whether  a texture file (which is being extracted from the StudioPro
          file and saved to disk) should be overwritten. If the user does  not
          want  the file, which already exists on disk, to be overwritten then
          the converter will skip it. If this checkbox is not enabled then any
          potential file overwrites will not be confirmed.

     -in-sspro-texture-dest-directory-type = [ use-input-file-directory | use-
          execution-directory | use-specific-directory ]
          Strata StudioPro files are unusual because they  embed  the  texture
          images  right  inside the scene file itself. This converter extracts
          these embedded images and stores them on disk as TIFF files  in  the
          directory controlled by this '-in-sspro-texture-dest-directory-type'
          option.

          The 'use-input-file-directory' option saves out the TIFF  images  to
          the  same  directory  where the Strata StudioPro input file was read
          from.

          The 'use-execution-directory' option saves out the  TIFF  images  to
          the directory where this translation program was executed from.

          The 'use-specific-directory' option saves out the TIFF images to the
          directory specified by the '-in-sspro-texture-dest-directory' option
          below.

     -in-sspro-texture-dest-directory = "a valid directory path"
          This option lists  a  directory  path  where  the  Strata  StudioPro
          embedded  bitmap  images  will be saved to disk as TIFF images. This
          directory  path  only  applies  while  the  '-in-sspro-texture-dest-
          directory-type' option is set to 'use-specific-directory'.

     -in-sspro-output-debug-info = [ yes | no ]
          If this option is set to 'yes'  then  the  contents  of  the  Strata
          StudioPro  file  will  be verbosely described and output to the file
          'debugstr.txt'.

     -in-sspro-report-stats = [ yes | no ]
          If this option is set to 'yes' then the converter  will  report  the
          number of objects, polygons, cameras, lights and materials created.


                                                                             3



Import-StudioPro()         Unix Programmer's Manual         Import-StudioPro()


     -in-sspro-read-cameras = [ yes | no ]
     -in-sspro-read-lights = [ yes | no ]
     -in-sspro-read-geometry = [ yes | no ]
     -in-sspro-read-materials = [ yes | no ]
          These switches allow specific sections of the Strata StudioPro  file
          to  be  excluded  or  included in the import process. All default to
          'yes' which means that all named entities will be read in. If set to
          'no' then the named section(s) will not be read into memory.

CURRENTLY SUPPORTED STUDIOPRO ENTITIES

     TCONE
     TCUBE
     TBEZIERMESH
     TBEZIERPATCH
     TDISC
     TENTITY
     TINSTANCE
     TGROUP
     TCAMERA
     TMODEL
     TMESH
     TDIRECTIONALLIGHT
     TPOSITIONALLIGHT
     TBULEMICMESH
     TSELECTIVEMESH
     TORDEREDBEZIERMESH
     TSPHERE
     TSPOTLIGHT
     TIMAGEMAP
     TRGBIMAGEMAP
     T2DRECT
     TATTRIBUTE
     T2DPOLYLINE
     T2DHOLE
     T2DPOLYGON
     TSHADER
     TMETALSHADER
     TPOLYLINE
     THOLE
     TPOLYGON
     TSURFACEMAP

CURRENTLY NON-SUPPORTED STUDIOPRO ENTITIES

     T3DPAINT
     TCUBEROUNDED
     TEXTERNALENTITY
     TSKINENTITY
     TSKINENTITYNEW
     TTRIANGLE
     TSMOOTHTRIANGLE
     TBLENDINGSHADER
     TEXTERNALSHADER
     TENVIRONMENT
     TSHADERENVIRONMENT


                                                                             4



Import-StudioPro()         Unix Programmer's Manual         Import-StudioPro()


     TEXTERNALENVIRONMENT
     THORIZONENVIRONMENT
     TPICTUREENVIRONMENT
     TRGBENVIRONMENT
     TLAYER
     TLINKAGES
     T2DENTITY
     T2DBEZIERCURVE
     T2DBEZIERHOLE
     T2DBEZIERREGION
     TCLOSEDRIB
     TOPENRIB
     T2DGROUP
     T2DOVAL
     T2DROUNDRECT
     TQUICKDISPLAYLIST










































                                                                             5

