

Import-trueSpace()         Unix Programmer's Manual         Import-trueSpace()


NAME
     imp_truespace - Caligari trueSpace geometry import filter

SYNOPSIS

     This man page describes the options specific to  the  trueSpace  geometry
     import converter.

EXAMPLE CONVERSION SYNTAX

     To convert a trueSpace file to Wavefront  using  the  default  parameters
     listed in the setup.ini file:

          pt -i wave -o wave filename.cob

     To convert a trueSpace file to VRML and  override  some  of  the  default
     options in setup.ini:

          pt -i true -in-true-debug = yes -o vrml filename.true

OVERVIEW

     This is a  highly  accurate  geometry  import  converter  that  reads  in
     Caligari  trueSpace '.cob' and '.scn' binary scene files. This is a 'load
     and render' converter that imports and  translates  all  aspects  of  the
     scene  file so that little or no modifications must be done in the target
     rendering program to produce equivalent results to that  created  by  the
     trueSpace renderer.

     The following are some of the features of this converter:

          All geometry is read in including the local axes  and  all  material
          assignments.

          Holes within  polygons  are  also  properly  converted  into  NuGraf
          compatible meshed polygons with holes.

          All (u,v) texture coordinates are read in and stored along with  the
          meshed polygon data.

          All three polygon faceting  modes  are  properly  handled:  faceted,
          autofacet  and 'smooth'. This allows proper smoothing of the data as
          per the Caligari trueSpace smoothing conventions.

          The original scene hierarchy is completely recreated, including  all
          groupings and their related transformations.

     In addition, this converter  reads  in  *every*  material  attribute  and
     accurately translates the shading parameters to equivalent NuGraf shading
     parameters. The NuGraf renderer will be able to render any trueSpace file
     with  little  or no modification with results that are almost exactly the
     same as within trueSpace. The following describes  some  of  the  shading
     parameter translations:





                                                                             1



Import-trueSpace()         Unix Programmer's Manual         Import-trueSpace()


          Flat, smooth and metal shading modes are translated properly.

          The 'metal' shading  mode  properly  takes  into  account  the  edge
          transparency dropoff.

          The 'shininess' parameter is  properly  decoded  into  three  NuGraf
          shading  parameters  of  diffuse, specular and ray-traced shininess.
          This decoding is quite  important  to  properly  recreate  trueSpace
          scenes.

          Cubic and spherical environment map are translated  into  equivalent
          NuGraf environment map types.

          Texture maps are properly translated, as well as the image filename,
          the u/v scaling factors and the u/v offset values.

          Likewise, the bump map textures and all of  its  related  parameters
          are properly translated.

CONVERTER LIMITATIONS

     trueSpace binary scene files do not include U/V tangent vectors which are
     typically  required  by other rendering programs in order to perform bump
     mapping. Thus, even though  the  bump  mapping  parameters  are  properly
     translated,  no  bump mapping will appear in the target rendering program
     because of this lack of U/V tangent vectors. To circumvent  this  problem
     you  will  have  to apply the U/V tangent vectors in the target rendering
     program (typically by assigning a 'texture projection' to  the  object(s)
     in question).

     At this time the only aspect of the file that  has  not  been  translated
     into  equivalent  NuGraf  renderer  parameters  are  the  three trueSpace
     procedural texture mapping functions: granite, marble and wood. These are
     highly specific to the trueSpace renderer.

     All texture filenames are stripped of their  pathnames  and  unrecognized
     image  file  types are translated to TIFF file types. For example, if the
     trueSpace image filename is  'c:\truespace\image.txr'  then  it  will  be
     translated to 'image.tif'.

     This converter does not read in the ASCII version of  Caligari  trueSpace
     files since they are not at all common.


COMMAND LINE OPTIONS

     The following options are specific to this import converter:

     -i true
          This is the optional command line option which  specifies  that  the
          input  data  is  in the trueSpace file format. If not specified then
          the converter will try to guess the input  file's  format  from  its
          file extension and then from the contents of its file. Note that the
          valid file extensions are .cob and .scn.  ASCII trueSpace files  are
          not accommodated.



                                                                             2



Import-trueSpace()         Unix Programmer's Manual         Import-trueSpace()


     -in-true-remove-dbl-sided-polygons = [ yes | no ]
          When trueSpace adds a single flat polygon to  a  scene  it  actually
          adds  two  duplicated polygons that are exactly the same except that
          the two polygons face in opposite directions.  These  doubled  sided
          polygons cause problems with many rendering programs so this option,
          when enabled, allows double sided polygons to be  deleted  from  the
          scene. It is enabled ('on') by default.

     -in-true-smooth = [ yes | no ]
          If 'yes', which is the default, then smoothed vertex normals will be
          computed  based  on  the  smoothing information contained within the
          trueSpace file; this will make the resulting object(s) appear to  be
          smooth.   If  set  to  'no' then no smoothing will be performed, and
          hence the resulting object(s) will appear to be  flat  shaded  since
          they have no vertex normals associated with them.

     -in-true-print-stats = [ yes | no ]
          If 'yes', which is the default, then statistics  will  be  displayed
          about the parsed input file.

     -in-true-print-warn = [ yes | no ]
          If 'yes' then any warnings output from the parser will be displayed.
          The default is 'no'.

     -in-true-debug = [ yes | no ]
          If 'yes' then verbose parsing information will be output to the file
          ASCII  'debugcob.txt'  located within the current working directory.
          The default is 'no'.






























                                                                             3

