

Import-VistaPro()          Unix Programmer's Manual          Import-VistaPro()


NAME
     imp_VistaPro - Vistapro Digital Elevation  Model  (DEM)  geometry  import
     filter

SYNOPSIS

     This man page describes the options specific to the Vistapro DEM geometry
     import converter.

EXAMPLE CONVERSION SYNTAX

     To convert a Vistapro DEM file to 3D Studio using the default  parameters
     listed in the setup.ini file:

          pt -i vpro -o 3ds filename.dem

     To convert a Vistapro DEM file to VRML and override some of  the  default
     options in setup.ini:

          pt -i vpro -in-vpro-skip-factor = 6 -o vrml filename.dem

OVERVIEW

     This geometry import converter imports, manipulates and converts  digital
     elevation model (DEM) data in the Vistapro format.

FEATURES OF THIS CONVERTER

     Vistapro DEM datasets  typically  contain  60000  or  more  quadrilateral
     polygons, or 1200000 triangles (for a 258x258 resolution sample). This is
     an enormous number of polygons for most 3d rendering programs so this DEM
     converter incorporates two unique options to overcome this problem:

          1) The converter can skip over samples in the dataset so  that  only
          every  n-th  sample  is used. Rather than importing 258x258 samples,
          the converter imports 51x51 samples (for a skip factor of  5)  which
          results in only 2601 quadrilateral polygons.

          2) Rather than store the entire DEM dataset in  single  object,  the
          DEM  converter breaks up the data into multiple smaller objects with
          a common parent. This  has  shown  to  be  an  effective  method  to
          speeding  up the wireframe redraws of the DEM data (by a factor of 2
          or 3), and makes interactive user  movement  of  a  3d  camera  much
          faster  since  each  sub-object  is only a few hundred polygons.  In
          addition,  certain  rendering  programs  (such  as  Okino's   NuGraf
          renderer)  use  much  less memory when many smaller objects are used
          rather than one large object with many  polygons.  By  default  each
          sub-object  stores  a  maximum  of  900 polygons; contrast this with
          other converters which lump  all  120,000  polygons  into  a  single
          object - few renderers will be able to render such a large object.

          3) A default 3d camera is added to the scene  which  views  the  DEM
          data from a pleasing angle.





                                                                             1



Import-VistaPro()          Unix Programmer's Manual          Import-VistaPro()


          4) u/v texture coordinates are added to the imported data so that  a
          bitmap image can be easily draped over the DEM data.

          5) The converter creates smoothed vertex normals for the DEM data so
          that it will appear to be smooth when rendered.

COMMAND LINE OPTIONS

     The following options are specific to this import converter:

     -i vpro
          This is the optional command line option which  specifies  that  the
          input data is in the Vistapro DEM file format. If not specified then
          the converter will try to guess the input  file's  format  from  its
          file extension (.dem) and then from the contents of its file.

     -in-vpro-print-statistics = [ yes | no ]
          If set to 'yes' then the converter will  print  out  the  number  of
          objects and polygons created.

     -in-vpro-add-default-camera = [ yes | no ]
          If set to 'yes' then the converter will add a default camera to  the
          scene which views the DEM data at a pleasing angle.

     -in-vpro-skip-factor = #
          This switch determines the quality of  the  imported  DEM  data  (it
          directly  controls how many polygons will be used to approximate the
          input DEM data). THIS IS AN IMPORTANT CONTROL PARAMETER!! A value of
          1  results in the highest quality mesh while higher values (2, 3, 4,
          etc) result in lower quality, but at the  benefit  of  reducing  the
          number  of  polygons  in  the input data. This number will cause the
          converter to 'skip' over every n-th input sample.  For  example,  if
          the  input  dataset  size is 258x258 samples, and the skip factor is
          set to 4, then the converter will actually read in the data as if it
          were  of  size  65x65  (258/4 = 65). This will produce 4225 polygons
          (65x65) instead of 66565 polygons. A value of 2 or 3 (16641 polygons
          to  7396  polygons) will produce good results for a final rendering,
          while values of 5 to 8 will produce small datasets  ideal  for  fast
          previews (2704 polygons to 1024 polygons).

     -in-vpro-sub-grid-size = #
          By default the DEM data will be cut up  into  several  smaller  sub-
          objects rather than having all of the DEM data clumped together into
          one huge object. This option controls how many polygons will be  put
          into  each  sub-object.  The  default  is  30  which  will cause 900
          polygons (30x30) to be stored in each sub-object. The valid range is
          5 to 100.

     -in-vpro-height-scaling-factor = #
          This option scales the height of the DEM data. It  default  to  1.0.
          Values  greater  than 1.0 will make the DEM data higher while values
          between 0.0 and 1.0 will make the DEM data shorter.

     -in-vpro-add-2d-txtr-coords = [ yes | no ]
          If set to 'yes' then u/v texture coordinates will be  added  to  the
          imported  dataset.  These texture coordinates will allow a 2d bitmap


                                                                             2



Import-VistaPro()          Unix Programmer's Manual          Import-VistaPro()


          image to be easily mapped to the surface of the  data.  Please  note
          that  the  texture  coordinates  are  aligned  with the mathematical
          bounding quadrilateral of the dataset, not the actual physical edges
          of  the data (this is because the physical edges of the data are not
          square or precise).

     -in-vpro-add-default-2d-texture = [ yes | no ]
          If  set  to  'yes'  then  a   default   2d   bitmap   texture   file
          ("default.tif")  will  be  linked  to  the  DEM data. This option is
          useful if you intend to apply a 2d bitmap image to the DEM data. The
          "-in-vpro-add-2d-txtr-coords" option must also be enabled.

     -in-vpro-texture-2d-u-repeat = 5

     -in-vpro-texture-2d-v-repeat = 5
          These two values determine how many times the 2d bitmap  texture  is
          to  repeat  across  the  DEM  data  surface  (see the "-in-vpro-add-
          default-2d-texture" option above). The default values  are  5  which
          will  make the texture repeat 5 times in the horizontal and vertical
          directions.

     -in-vpro-add-default-3d-texture = [ yes | no ]
          If  set  to  'yes'  then  a  NuGraf  "mountain"  procedural  texture
          definition  will  be  added to the scene and assigned to the current
          shader (useful for rendering the DEM data with the NuGraf renderer).
          This  texture  varies  the  color  of  the DEM data according to the
          elevation and slope of a polygon (the color varies from  greens,  to
          browns  to  whites at the highest altitudes).  Please note that this
          texture tends to be slow to  compute  due  to  the  turbulence  math
          functions;  a  better  alternative  would  be  to assign a 2d bitmap
          texture.

     -in-vpro-create-one-object = [ yes | no ]
          If set to 'yes' then one single object is created  for  all  of  the
          imported  data  rather  than having the data broken up into multiple
          smaller sub-objects (the default). The converter automatically  sets
          this to 'yes' (internally) if the selected output format is to be 3D
          Studio (this is because 3D Studio requires all polygons to be inside
          a  single object so that its smoothing algorithm will work properly;
          if multiple objects are used then the vertex normals will not be the
          same where the sub-objects meet and hence "cracks" may appear at the
          junctions).

     -in-vpro-triangulate-data = [ yes | no ]
          If set to 'yes' then the DEM data  will  be  imported  as  triangles
          instead  of  4  sided  polygons.  This is sometimes useful to enable
          since 4-sided DEM data polygons are not planar.

LIMITATIONS

     If exporting to 3D Studio then all of the DEM data must  be  exported  as
     one  object  so  that  proper smoothing occurs between the sub-chunks. 3D
     Studio has a limit of 64k vertices and 64k polygons, therefore the  chunk
     size  must  be  set  appropriately  to  limit  the number of polygons and
     vertices output (the number  of  polygons  created  can  be  verified  by
     setting the '-in-vpro-print-statistics' option to 'yes' and checking that


                                                                             3



Import-VistaPro()          Unix Programmer's Manual          Import-VistaPro()


     the number of polygons created is less than 65536).

























































                                                                             4

